# When bootstrapping an arch, omit the -demos subpackage.
%bcond_without vulkan
%bcond_without glvnd
%bcond_without wayland
%bcond_with libva
%bcond_with source

%global with_hardware 1
%global with_r300 1
%global with_r600 1
%global with_vdpau 1
%global with_vaapi 1
%global with_nine 1
#global with_omx 1
#global with_opencl 1
%global base_drivers nouveau,r100,r200

%ifarch %{ix86}
%define ix86_drivers ,i915,i965
%endif
#ifarch x86_64
#define amd64_drivers ,i915,i965
#endif
%define dri_drivers %{base_drivers}%{?ix86_drivers}%{?amd64_drivers}

%global with_iris   1
%global with_vmware 1
%global with_xa     1
%if %{with vulkan}
%global vulkan_drivers swrast,intel,amd
%else
%global vulkan_drivers %{nil}
%endif
%global with_radeonsi 1
%global with_asm 1


%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}

Summary:        Mesa graphics libraries
Summary(ja):    Mesa グラフィックスライブラリ
Name:           mesa
Version:        22.2.0
Release:        1%{?_dist_release}
Group:          system
Vendor:         Project Vine
Distribution:   Vine Linux

License:        MIT
URL:            https://www.mesa3d.org/
Source0:        https://mesa.freedesktop.org/archive/%{name}-%{version}.tar.xz

# src/gallium/auxiliary/postprocess/pp_mlaa* have an ... interestingly worded license.
# Source4 contains email correspondence clarifying the license terms.
# Fedora opts to ignore the optional part of clause 2 and treat that code as 2 clause BSD.
Source4:        Mesa-MLAA-License-Clarification-Email.txt

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: meson
BuildRequires: pkgconfig
BuildRequires: flex, bison
BuildRequires: libstdc++-static
BuildRequires: libdrm-devel >= 2.4.60
BuildRequires: libXxf86vm-devel
BuildRequires: expat-devel >= 2.0
BuildRequires: xorg-x11-proto-devel >= 7.4
BuildRequires: xorg-x11-server-sdk
%if 0%{?with_hardware}
BuildRequires:  kernel-headers
%endif
BuildRequires: makedepend
BuildRequires: libXext-devel
BuildRequires: libXfixes-devel
BuildRequires: libxcb-devel
BuildRequires: libXdamage-devel
BuildRequires: libXi-devel
BuildRequires: libXmu-devel
BuildRequires: libXrandr-devel
BuildRequires: libxshmfence-devel
BuildRequires: eudev-libudev-devel
BuildRequires: llvm-devel >= 9.0.0
%if 0%{?with_opencl}
BuildRequires: clang-devel
BuildRequires: libclc-devel
%endif
BuildRequires: python3-devel
BuildRequires: python3-rpm-macros
BuildRequires: python3-setuptools
BuildRequires: python3-mako
BuildRequires: libxml2-python
%if 0%{?with_vdpau}
BuildRequires: libvdpau-devel >= 1.1
%endif
%if 0%{?with_vaapi}
BuildRequires: libva-devel
%endif
BuildRequires: elfutils-libelf-devel
BuildRequires: zlib-devel
%if %{with vulkan}
BuildRequires: vulkan-devel
BuildRequires: glslang-devel
%endif
%if %{with glvnd}
BuildRequires: libglvnd-devel
%endif
%if %{with wayland}
#BuildRequires:  pkgconfig(wayland-scanner)
#BuildRequires:  pkgconfig(wayland-protocols) >= 1.25.0
#BuildRequires:  pkgconfig(wayland-client) >= 1.20.0
#BuildRequires:  pkgconfig(wayland-server) >= 1.20.0
#BuildRequires:  pkgconfig(wayland-egl-backend) >= 3
BuildRequires:  wayland-devel
BuildRequires:  wayland-protocols-devel
%endif


%description
Mesa


%package libGL
Summary: Mesa libGL runtime libraries
Summary(ja): Mesa libGL ランタイムライブラリ
Group: system
%if %{with glvnd}
Requires: libglvnd-glx%{?_isa}
%endif
Provides: libGL
Obsoletes: Mesa, XFree86-gl, XOrg-gl

%description libGL
Mesa libGL runtime libraries and DRI drivers.


%package libGL-devel
Summary: Mesa libGL development package
Summary(ja): Mesa libGL 開発パッケージ
Group: programming
Provides: libGL-devel
Requires: mesa-libGL = %{version}-%{release}
Requires: libX11-devel
Requires: libXxf86vm-devel
Requires: libXdamage-devel
Requires: libXfixes-devel
Requires: libXext-devel
Requires: libdrm-devel
%if %{with glvnd}
Requires: libglvnd-devel%{?_isa}
%endif
Obsoletes: Mesa-devel, XFree86-gl-devel, XOrg-gl-devel

%description libGL-devel
Mesa libGL development package


%package dri-drivers
Summary: Mesa-based DRI drivers
Summary(ja): Mesa ベースの DRI ドライバ
Group: system
Obsoletes: mesa-libGL < 8.0.4

%description dri-drivers
Mesa-based DRI drivers.


%package vdpau-drivers
Summary: Mesa-based VDPAU drivers
Summary(ja): Mesa ベースの VDPAU ドライバ
Group: system
Requires: libvdpau

%description vdpau-drivers
Mesa-based VDPAU drivers.


%package libEGL
Summary: Mesa libEGL runtime libraries
Summary(ja): Mesa libEGL ランタイムライブラリ
Group: system
Requires: libdrm >= 2.4.24-1
%if %{with glvnd}
Requires: libglvnd-egl%{?_isa}
%endif

%description libEGL
Mesa libEGL runtime libraries


%package libEGL-devel
Summary: Mesa libEGL development package
Summary(ja): Mesa libEGL 開発パッケージ
Group: programming
Requires: mesa-libEGL = %{version}-%{release}
%if %{with glvnd}
Requires: libglvnd-devel%{?_isa}
%endif
Provides: libEGL-devel
Provides: libEGL-devel%{?_isa}

%description libEGL-devel
Mesa libEGL development package


%package libOSMesa
Summary: Mesa offscreen rendering libraries
Summary(ja): Mesa オフスクリーンレンダリングライブラリ
Group: system
Provides: libOSMesa

%description libOSMesa
Mesa offscreen rendering libraries


%package libOSMesa-devel
Summary: Mesa offscreen rendering development package
Summary(ja): Mesa オフスクリーンレンダリング開発パッケージ
Group: programming
Requires: mesa-libOSMesa = %{version}-%{release}

%description libOSMesa-devel
Mesa offscreen rendering development package


%package libgbm
Summary: Mesa gbm library
Summary(ja): Mesa gbm ライブラリ
Group: system
Provides: libgbm

%description libgbm
Mesa gbm runtime library.


%package libgbm-devel
Summary: Mesa libgbm development package
Summary(ja): Mesa gbm ライブラリ開発パッケージ
Group: programming
Provides: libgbm-devel
Requires: mesa-libgbm = %{version}-%{release}

%description libgbm-devel
Mesa libgbm development package


%package libglapi
Summary: Mesa shared glapi
Group: system
Provides: libglapi
Obsoletes: mesa-libGLES < 21.0.0

%description libglapi
Mesa shared glapi


%package libxatracker
Summary: Mesa XA state tracker for vmware
Summary(ja): VMware 用 Mesa XA ステートトラッカー
Group: system
Provides: libxatracker

%description libxatracker
Mesa XA state tracker for vmware

%package libxatracker-devel
Summary: Mesa XA state tracker development package
Summary(ja): Mesa XA ステートトラッカー開発パッケージ
Group: programming
Requires: mesa-libxatracker = %{version}-%{release}
Provides: libxatracker-devel

%description libxatracker-devel
Mesa XA state tracker development package


%if 0%{?with_nine}
%package libd3d
Group:          system
Summary:        Mesa Direct3D9 state tracker

%description libd3d
%{summary}.


%package libd3d-devel
Summary:        Mesa Direct3D9 state tracker development package
Group:          programming
Requires:       %{name}-libd3d%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}

%description libd3d-devel
%{summary}.
%endif


%package source
Summary: Mesa source code required to build X server
Summary(ja): X サーバをビルドするために必要な Mesa ソースコード
Group: programming

%description source
The mesa-source package provides the minimal source code needed to
build DRI enabled X servers, etc.


# compat32
%package -n compat32-%{name}-libGL
Summary: Mesa libGL runtime libraries and DRI drivers
Summary(ja): Mesa libGL ランタイプライブラリおよび DRI ドライバ
Group: system
Requires: %{name}-libGL = %{version}-%{release}
Requires: compat32-libdrm >= 2.4.5

%description -n compat32-%{name}-libGL
Mesa libGL runtime libraries and DRI drivers.

%package -n compat32-%{name}-libGL-devel
Summary: Mesa libGL development package
Summary(ja): Mesa libGL 開発パッケージ
Group: programming
Requires: compat32-%{name}-libGL = %{version}-%{release}
Requires: %{name}-libGL-devel = %{version}-%{release}
Requires: compat32-libX11-devel
Requires: compat32-libdrm-devel

%description -n compat32-%{name}-libGL-devel
Mesa libGL development package


%package -n compat32-%{name}-libEGL
Summary: Mesa libEGL runtime libraries
Summary(ja): Mesa libEGL ランタイムライブラリ
Group: system
Requires: compat32-libdrm >= 2.4.24-1

%description -n compat32-%{name}-libEGL
Mesa libEGL runtime libraries

%package -n compat32-%{name}-libEGL-devel
Summary: Mesa libEGL development package
Summary(ja): Mesa libEGL 開発パッケージ
Group: programming
Requires: mesa-libEGL = %{version}-%{release}
Requires: compat32-mesa-libEGL = %{version}-%{release}

%description -n compat32-%{name}-libEGL-devel
Mesa libEGL development package


%package -n compat32-%{name}-libOSMesa
Summary: Mesa offscreen rendering libraries
Summary(ja): Mesa オフスクリーンレンダリングライブラリ
Group: system
Requires: %{name}-libOSMesa

%description -n compat32-%{name}-libOSMesa
Mesa offscreen rendering libraries


%package -n compat32-%{name}-libOSMesa-devel
Summary: Mesa offscreen rendering development package
Summary(ja): Mesa オフスクリーンレンダリング開発パッケージ
Group: programming
Requires: compat32-%{name}-libOSMesa = %{version}-%{release}
Requires: %{name}-libOSMesa-devel = %{version}-%{release}

%description -n compat32-%{name}-libOSMesa-devel
Mesa offscreen rendering development package


%package -n compat32-%{name}-libxatracker
Summary: Mesa XA state tracker for vmware
Summary(ja): VMware 用 Mesa XA ステートトラッカー
Group: system
Requires: %{name}-libxatracker

%description -n compat32-%{name}-libxatracker
Mesa XA state tracker for vmware


%package -n compat32-%{name}-libgbm
Summary: Mesa gbm library
Summary(ja): Mesa gbm ライブラリ
Group: system
Requires: %{name}-libgbm

%description -n compat32-%{name}-libgbm
Mesa gbm runtime library.


%package -n compat32-%{name}-libglapi
Summary: Mesa shared glapi
Group: system
Requires: %{name}-libglapi

%description -n compat32-%{name}-libglapi
Mesa shared glapi


%package -n compat32-%{name}-dri-drivers
Summary: Mesa-based DRI drivers
Summary(ja): Mesa ベースの DRI ドライバ
Group: system
Obsoletes: mesa-libGL < 8.0.4

%description -n compat32-%{name}-dri-drivers
Mesa-based DRI drivers.


%if %{with vulkan}
%package vulkan-drivers
Summary:        Mesa Vulkan drivers
Group:          system
Requires:       vulkan%{_isa}

%description vulkan-drivers
The drivers with support for the Vulkan API.


%package vulkan-devel
Summary:        Mesa Vulkan development files
Group:          programming
Requires:       %{name}-vulkan-drivers%{?_isa} = %{?epoch:%{epoch}}%{version}-%{release}
Requires:       vulkan-devel

%description vulkan-devel
Headers for development with the Vulkan API.
%endif


%debug_package


%prep
%setup -n %{name}-%{version}

cp %{SOURCE4} docs/


%build
export PYTHON=%{__pythpn3}

%meson \
%if %{with wayland}
  -Dplatforms=x11,wayland \
%else
  -Dplatforms=x11 \
%endif
  -Ddri3=enabled \
%if 0%{?with_hardware}
  -Dgallium-drivers=swrast,virgl,nouveau%{?with_r300:,r300}%{?with_crocus:,crocus}%{?with_iris:,iris}%{?with_vmware:,svga}%{?with_radeonsi:,radeonsi}%{?with_r600:,r600}%{?with_freedreno:,freedreno}%{?with_etnaviv:,etnaviv}%{?with_tegra:,tegra}%{?with_vc4:,vc4}%{?with_v3d:,v3d}%{?with_kmsro:,kmsro}%{?with_lima:,lima}%{?with_panfrost:,panfrost}%{?with_vulkan:,zink} \
%else
  -Dgallium-drivers=swrast,virgl \
%endif
  -Dgallium-vdpau=%{?with_vdpau:enabled}%{!?with_vdpau:disabled} \
  -Dgallium-xvmc=disabled \
  -Dgallium-omx=%{?with_omx:bellagio}%{!?with_omx:disabled} \
  -Dgallium-va=%{?with_vaapi:enabled}%{!?with_vaapi:disabled} \
  -Dgallium-xa=%{?with_xa:enabled}%{!?with_xa:disabled} \
  -Dgallium-nine=%{?with_nine:true}%{!?with_nine:false} \
  -Dgallium-opencl=%{?with_opencl:icd}%{!?with_opencl:disabled} \
  -Dvulkan-drivers=%{?vulkan_drivers} \
  -Dvulkan-layers=device-select \
  -Dshared-glapi=enabled \
  -Dgles1=disabled \
  -Dgles2=enabled \
  -Dopengl=true \
  -Dgbm=enabled \
  -Dglx=dri \
  -Degl=enabled \
%if %{with glvnd}
  -Dglvnd=true \
%else
  -Dglvnd=false \
%endif
  -Dmicrosoft-clc=disabled \
  -Dllvm=enabled \
  -Dshared-llvm=enabled \
  -Dvalgrind=%{?with_valgrind:enabled}%{!?with_valgrind:disabled} \
  -Dbuild-tests=false \
  -Dselinux=false \
  -Dosmesa=true \
  %{nil}
%meson_build


%install
%meson_install

# libvdpau opens the versioned name, don't bother including the unversioned
rm -f %{buildroot}%{_libdir}/vdpau/*.so
# likewise glvnd
%if %{with glvnd}
rm -f %{buildroot}%{_libdir}/libGLX_mesa.so
rm -f %{buildroot}%{_libdir}/libEGL_mesa.so
# XXX can we just not build this
rm -f %{buildroot}%{_libdir}/libGLES*

# glvnd needs a default provider for indirect rendering where it cannot
# determine the vendor
ln -s %{_libdir}/libGLX_mesa.so.0 %{buildroot}%{_libdir}/libGLX_system.so.0
%endif

# strip out useless headers
rm -f %{buildroot}%{_includedir}/GL/w*.h

pushd $RPM_BUILD_ROOT%{_libdir}
rm -f xorg/modules/drivers/modesetting_drv.so
popd

# this keeps breaking, check it early.  note that the exit from eu-ftr is odd.
pushd %{buildroot}%{_libdir}
for i in libOSMesa*.so libGL.so ; do
    eu-findtextrel $i && exit 1
done
popd

%if %{with source}
# Install the source needed to build the X server.  The egreps are just
# stripping out unnecessary dirs; only tricky bit is the [^c] to make sure
# .../dri/common is included.
%define mesasourcedir %{_datadir}/mesa/source
mkdir -p $RPM_BUILD_ROOT/%{mesasourcedir}
( find src -name \*.[ch] ; find include -name \*.h ) |
    egrep -v '^src/(glu|glw)' |
    egrep -v '^src/mesa/drivers/(directfb|dos|fbdev|glide|ggi|osmesa)' |
    egrep -v '^src/mesa/drivers/(windows|dri/[^c])' |
    xargs tar cf - --mode a=r |
       (cd $RPM_BUILD_ROOT/%{mesasourcedir} && tar xf -)
%endif


%files libGL
%defattr(-,root,root,-)
%{_libdir}/libGLX_mesa.so.0*
%{_libdir}/libGLX_system.so.0*

%files libGL-devel
%dir %{_includedir}/GL/internal
%{_includedir}/GL/internal/dri_interface.h
%{_libdir}/pkgconfig/dri.pc
%{_libdir}/libglapi.so

%files libEGL
%{_datadir}/glvnd/egl_vendor.d/50_mesa.json
%{_libdir}/libEGL_mesa.so.0*

%files libEGL-devel
%dir %{_includedir}/EGL
%{_includedir}/EGL/eglmesaext.h
%{_includedir}/EGL/eglextchromium.h

%files libOSMesa
%{_libdir}/libOSMesa.so.8*

%files libOSMesa-devel
%dir %{_includedir}/GL
%{_includedir}/GL/osmesa.h
%{_libdir}/libOSMesa.so
%{_libdir}/pkgconfig/osmesa.pc

%files libglapi
%{_libdir}/libglapi.so.0
%{_libdir}/libglapi.so.0.*

%files libgbm
%{_libdir}/libgbm.so.1
%{_libdir}/libgbm.so.1.*

%files libgbm-devel
%{_libdir}/libgbm.so
%{_includedir}/gbm.h
%{_libdir}/pkgconfig/gbm.pc

%files libxatracker
%{_libdir}/libxatracker.so.2
%{_libdir}/libxatracker.so.2.*

%files libxatracker-devel
%{_libdir}/libxatracker.so
%{_includedir}/xa_tracker.h
%{_includedir}/xa_composite.h
%{_includedir}/xa_context.h
%{_libdir}/pkgconfig/xatracker.pc

%if 0%{?with_nine}
%files libd3d
%dir %{_libdir}/d3d/
%{_libdir}/d3d/*.so.*

%files libd3d-devel
%{_libdir}/pkgconfig/d3d.pc
%{_includedir}/d3dadapter/
%{_libdir}/d3d/*.so
%endif

%files dri-drivers
%dir %{_libdir}/dri
%{_libdir}/dri/*_dri.so
%{_libdir}/dri/*_drv_video.so
%dir %{_datadir}/drirc.d
%config(noreplace) %{_datadir}/drirc.d/*
%if 0%{?with_opencl}
%dir %{_libdir}/gallium-pipe
%{_libdir}/gallium-pipe/*.so
%endif

%files vdpau-drivers
%{_libdir}/vdpau/libvdpau_nouveau.so.1*
%{_libdir}/vdpau/libvdpau_r300.so.1*
%{_libdir}/vdpau/libvdpau_r600.so.1*
%{_libdir}/vdpau/libvdpau_radeonsi.so.1*

%if %{with vulkan}
%files vulkan-drivers
%{_libdir}/libvulkan_lvp.so
%{_datadir}/vulkan/icd.d/lvp_icd.*.json
%{_libdir}/libVkLayer_MESA_device_select.so
%{_datadir}/vulkan/implicit_layer.d/VkLayer_MESA_device_select.json
%if 0%{?with_hardware}
%ifarch %{ix86} x86_64
%{_libdir}/libvulkan_intel.so
%{_datadir}/vulkan/icd.d/intel_icd.*.json
%endif
%{_libdir}/libvulkan_radeon.so
%{_datadir}/vulkan/icd.d/radeon_icd.*.json
%endif

%files vulkan-devel
%endif

%if %{with source}
# We constructed this dir carefully, so just slurp in the whole thing.
%files source
%defattr(-,root,root,-)
%{mesasourcedir}
%endif

# compat32
%if %{build_compat32}
%files -n compat32-%{name}-libGL
%{_libdir}/libGLX_mesa.so.0*
%{_libdir}/libGLX_system.so.0*

%files -n compat32-%{name}-libGL-devel
%{_libdir}/libglapi.so

%files -n compat32-%{name}-libEGL
%{_libdir}/libEGL_mesa.so.0*

%files -n compat32-%{name}-libEGL-devel

%files -n compat32-%{name}-libOSMesa
%{_libdir}/libOSMesa.so.*

%files -n compat32-%{name}-libOSMesa-devel
%{_libdir}/libOSMesa.so

%files -n compat32-%{name}-libxatracker
%{_libdir}/libxatracker.so.2
%{_libdir}/libxatracker.so.2.*

%files -n compat32-%{name}-libglapi
%{_libdir}/libglapi.so.0
%{_libdir}/libglapi.so.0.*

%files -n compat32-%{name}-libgbm
%{_libdir}/libgbm.so.1
%{_libdir}/libgbm.so.1.*

%files -n compat32-%{name}-dri-drivers
%dir %{_libdir}/dri
%{_libdir}/dri/*_dri.so
%{_libdir}/dri/*_drv_video.so
%endif


%changelog
* Thu Sep 22 2022 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 22.2.0-1
- updated to 22.1.5.
- built with llvm-15.

* Thu Jun 16 2022 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 22.1.1-1
- updated to 22.1.1.
- built with llvm-14.

* Fri Oct 22 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 21.2.4-1
- updated to 21.2.4.
- built with llvm-13.
- dropped Patch0 and 3.

* Sat Apr 17 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 21.0.2-1
- updated to 21.0.2.
- built with llvm-12.
- dropped Patch1: fixed in upstream.

* Sat Mar 27 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 21.0.1-1
- updated to 21.0.1.
- dropped Patch3.
- imported Patch0 from rawhide (not applied now).
- imported Patch1 from rawhide.
- built with libglvnd.

* Thu Oct 15 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 20.2.1-1
- updated to 20.2.1.

* Thu Jul 30 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 20.1.4-1
- updated to 20.1.4.
- dropped Patch7 and 1000: fixed in upstream.

* Thu Mar 26 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 19.3.5-1
- updated to 19.3.5.
- imported Patch1000 from upstream for llvm10.

* Wed Oct 02 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 19.2.0-1
- updated to 19.2.0.

* Fri Sep 20 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 19.1.7-1
- updated to 19.1.7.
- dropped Patch1.
- imported Patche7 from rawhide.
- switched the build-system to meson.

* Wed Dec 05 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 18.2.6-1
- updated to 18.2.6.
- dropped Patch2, 4, 10 and 11.

* Mon Jan 01 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 17.3.1-1
- updated to 17.3.1.
- replaced all patches from rawhide.

* Fri Aug  5 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 11.2.2-1
- updated to 11.2.2.
- dropped Patch99: fixed in upstream.

* Thu Jun 30 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.1.4-2
- rebuild with gcc-5.4.0

* Thu May 12 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.1.4-1
- update to 11.1.4

* Thu May 05 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.1.3-1
- update to 11.1.3

* Sat Feb 13 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.0.9-2
- create compat32-mesa-dri-drivers subpackage

* Sun Jan 24 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.0.9-1
- update to 11.0.9

* Thu Dec 17 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.0.7-1
- update to 11.0.7

* Sun Nov 22 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.0.6-1
- update to 11.0.6

* Thu Nov 12 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.0.5-1
- update to 11.0.5

* Sat Oct 31 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 11.0.4-1
- update to 11.0.4

* Tue Jul 07 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.5.9-1
- update to 10.5.9

* Thu Jun 11 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 10.5.7-2
- rebuilt with llvm 3.6.1
- added %%post and %%postun section for libglapi and libgbm

* Wed Jun 10 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.5.7-1
- update to 10.5.7

* Fri May 29 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.5.6-1
- update to 10.5.6

* Sat May 16 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.5.5-1
- update to 10.5.5

* Sun May 03 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.5.4-1
- update to 10.5.4

* Sun Apr 19 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.5.3-1
- update to 10.5.3

* Sat Apr 04 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.4.7-1
- update to 10.4.7

* Sun Mar 08 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.4.6-1
- update to 10.4.6

* Sun Feb 22 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.4.5-1
- update to 10.4.5

* Sun Feb 08 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.4.4-1
- update to 10.4.4

* Sun Dec 07 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.3.5-1
- update to 10.3.5

* Sun Nov 23 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.3.4-1
- update to 10.3.4

* Wed Nov 19 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.3.3-1
- update to 10.3.3

* Tue Oct 28 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.3.2-1
- update to 10.3.2

* Wed Aug 27 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 10.2.6-1
- update to 10.2.6

* Tue Jul 15 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.2.3-2
- remove pc file from compat32 package

* Thu Jul 10 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 10.2.3-1
- update to 10.2.3

* Sun Jul 06 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.1.3-3
- rebuild with libffi-3.0.13

* Tue Jun 17 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 10.1.3-2
- change BuildRequires: eudev-libudev-devel instead of libudev-devel

* Wed May 14 2014 Daisuke SUZUKI <daisuke@linux.or.jp> 10.1.3-1
- update to 10.1.3
- add BR: libxshmfence-devel

* Mon Mar 24 2014 Daisuke SUZUKI <daisuke@linux.or.jp> 10.0.4-1
- update to 10.0.4

* Mon Oct 28 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.2-1
- update to 9.2.2
- add BR: libvdpau-devel, elfutils-libelf-devel, zlib-devel
- add BR: llvm-devel >= 3.3, libdrm-devel >= 2.4.46

* Sun Jun 02 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 9.0.1-3
- add Patch0 (mesa-9.0-CVE-2013-1993.patch)

* Sun Dec 02 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 9.0.1-2
- rebuild with llvm-3.1
- add radeonsi driver

* Wed Nov 21 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 9.0.1-1
- update to mesa-9.0.1

* Sat Nov 17 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 9.0-1
- update to mesa-9.0
- split off libGLU and gl-manpages to external package
- add libxatracker, libgbm

* Thu Jul 12 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 8.0.4-1
- update to 8.0.4
- remove BR: freeglut-devel
- split DRI drivers to mesa-dri-drivers

* Sat Feb 25 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 8.0.1-1
- update to 8.0.1
- drop unneeded patches
- drop old-old dri drivers
- add BR: libxml2-python

* Sun Jan 22 2012 NAKAMURA Kenta <kenta@vinelinux.org> 7.11.2-2
- rebuilt with llvm-3.0
- added Patch9: fix build with LLVM 3.0

* Thu Dec 29 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 7.11.2-1
- new upstram release

* Thu Aug 25 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 7.11-1
- update to 7.11
- use r[36]00g gallium driver as default.
- add BR: llvm-devel
- drop xorg-x11-drv-vmwgfx
- drop dri modules from compat32-mesa-libGL

* Sat Apr 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 7.10.3-1
- update to 7.10.3
- use r300/r600 classic driver for default.
  - install gallium r[36]00 as r[36]00g

* Sat Apr 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 7.10.2-2
- add patch50 from upstream fix
- enable parallel build
- use standard CFLAGS

* Thu Apr 07 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 7.10.2-1
- update to 7.10.2

* Fri Mar 25 2011 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.10.1-2
- dropped "BR: libtalloc-devel" (no longer needed).

* Fri Mar 11 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 7.10.1-1
- update to 7.10.1
- drop osmesa16 and osmesa32
- build with udev, egl and gles
- enable gallium r600 driver
- add libEGL/libGLES subpackage
- add Patch40 to fix build failure
- BR: libdrm-devel >= 2.4.24
- BR: libudev-devel

* Fri Jan 28 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 7.10-1
- update to 7.10
- split mesa-demos and glx-utils to their own source package.
- add BR: libtalloc-devel

* Wed Sep 22 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 7.8.2-1
- update to 7.8.2
- add Patch40,41 to fix build failure
- add Source10 to build with libdrm-2.4.21
- add BR: kernel-headers, xorg-x11-server-sdk

* Thu Apr  8 2010 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 7.8.1-2
- rebuilt with gcc-4.4.3-5 on ppc
- temporarily don't use "-Os" on ppc (a toolchain bug?)

* Tue Apr 06 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 7.8.1-1
- update to 7.8.1

* Mon Mar 29 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 7.8-1
- update to 7.8 release
- add xorg-x11-drv-vmwgfx subpackage for VMware GFX DDX driver

* Thu Mar 11 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 7.8-0.1.git20100217
- update to 7.8 branch from git

* Tue Jan 19 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 7.6.1-1
- update to 7.6.1 release

* Thu Dec 10 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.6.1-0.2.rc3
- update to 7.6.1-rc3

* Sat Nov 28 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.6.1-0.1.rc1
- update to 7.6.1-rc1

* Tue Nov 24 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.6-1
- new upstream release
- add R: libXxf86vm-devel, libXdamage-devel, libXfixes-devel,
  libXext-devel and libdrm-devel to mesa-libGL-devel

* Sat Sep 12 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.4.4-1
- new upstream release

* Sun Jun 28 2009 NAKAMURA Kenta <kenta@vinelinux.org> 7.4.1-2
- added compat32 subpackage for x86_64 arch support.

* Thu Apr 30 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.4.1-1
- new upstream release
- BR: libdrm-devel >= 2.4.9

* Sun Mar 22 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.3-1
- new upstream release
- BR: libdrm-devel >= 2.4.5
- drop mach64
- update patches from fedora

* Tue Oct 21 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.2-2
- add BR: libdrm-devel >= 2.4.0-3

* Mon Oct 20 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.2-1
- new upstreal release

* Thu Sep 04 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.1-4
- update to 7.1 release

* Thu Jul 24 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.1-3.rc3
- update to 7.1-rc3

* Sat Jul 05 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.1-2.rc1
- include missing swrast_dri.so to %%files list

* Tue Jul 01 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.1-1.rc1
- update to 7.1-rc1

* Thu May 22 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.0.3-2
- add Patch100 to disable 915tex driver

* Mon May 12 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.0.3-1
- new upstream release

* Sun Jan 20 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.0.2-0vl1
- build with freeglut

* Thu Jan 17 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 7.0.2-0vl0
- initial build for Vine Linux(bootstrap)

* Tue Jan 01 2008 Dave Airlie <airlied@redhat.com> 7.0.2-2
- mesa-7.0.2-stable-branch.patch: add in mesa 7.0.2 stable patches so far

* Tue Jan 01 2008 Dave Airlie <airlied@redhat.com> 7.0.2-1
- update to Mesa 7.0.2 final
- mesa-7.0.2-rx00-vertprog-num-temps-off-by-one.patch - fixes for maniadrive
- mesa-7.0.2-t_vp_build-use-less-temps.patch - fixes for maniadrive

* Thu Oct 18 2007 Dave Airlie <airlied@redhat.com> 7.0.1-7
- mesa-7.0.1-stable-branch.patch - Updated with more fixes from stable
- mesa-7.0.1-r300-fix-writemask.patch - fix r300 fragprog writemask
- mesa-7.0.1-r200-settexoffset.patch - add zero-copy TFP support for r200

* Fri Sep 28 2007 Dave Airlie <airlied@redhat.com> 7.0.1-6
- mesa-7.0.1-stable-branch.patch - Updated to close to 7.0.2-rc1
- This contains the fixes made to the upstream Mesa stable branch
  including fixes for 965 vblank interrupt issues along with a fix
  in the kernel - remove patches that already upstream.
- mesa-6.5.2-hush-synthetic-visual-warning.patch - dropped
- mesa-7.0-i-already-defined-glapi-you-twit.patch - dropped
- mesa-7.0.1-965-sampler-crash.patch - dropped

* Thu Sep 06 2007 Adam Jackson <ajax@redhat.com> 7.0.1-5
- mesa-7.0.1-965-sampler-crash.patch: Fix a crash with 965 in Torcs. (#262941)

* Tue Aug 28 2007 Adam Jackson <ajax@redhat.com> 7.0.1-4
- Rebuild for new libexpat.

* Wed Aug 15 2007 Dave Airlie <airlied@redhat.com> - 7.0.1-3
- mesa-7.0.1-stable-branch.patch - Add patches from stable branch
  includes support for some Intel chipsets
- mesa-7.0-use_master-r300.patch - Add r300 driver from master

* Tue Aug 14 2007 Dave Airlie <airlied@redhat.com> - 7.0.1-2
- missing build requires for Xfixes-devel and Xdamage-devel

* Mon Aug 13 2007 Dave Airlie <airlied@redhat.com> - 7.0.1-1
- Rebase to upstream 7.0.1 release
- ajax provided patches: for updated selinux awareness, build config
- gl visibility and picify were fixed upstream
- OS mesa library version are 6.5.3 not 7.0.1 - spec fix

* Wed Jul 25 2007 Jesse Keating <jkeating@redhat.com> - 6.5.2-16
- Rebuild for RH #249435

* Tue Jul 24 2007 Adam Jackson <ajax@redhat.com> 6.5.2-15
- Add dri_interface.h to mesa-libGL-devel, and conflict with
  xorg-x11-proto-devel versions that attempted to provide it.

* Tue Jul 10 2007 Adam Jackson <ajax@redhat.com> 6.5.2-14
- Add mesa-demos subpackage. (#247252)

* Mon Jul 09 2007 Adam Jackson <ajax@redhat.com> 6.5.2-13
- mesa-6.5.2-radeon-backports-231787.patch: One more fix for r300. (#231787)

* Mon Jul 09 2007 Adam Jackson <ajax@redhat.com> 6.5.2-12
- Don't install header files for APIs that we don't provide. (#247390)

* Fri Jul 06 2007 Adam Jackson <ajax@redhat.com> 6.5.2-11
- mesa-6.5.2-via-respect-my-cliplist.patch: Backport a via fix. (#247254)

* Tue Apr 10 2007 Adam Jackson <ajax@redhat.com> 6.5.2-10
- mesa-6.5.2-radeon-backports-231787.patch: Backport various radeon bugfixes
  from git. (#231787)

* Wed Apr 04 2007 Adam Jackson <ajax@redhat.com> 6.5.2-9
- mesa-6.5.2-bindcontext-paranoia.patch: Paper over a crash when doBindContext
  fails, to avoid, for example, crashing the server when using tdfx but
  without glide3 installed.

* Thu Mar 08 2007 Adam Jackson <ajax@redhat.com> 6.5.2-8
- Hush the (useless) warning about the synthetic visual not being supported.

* Fri Mar 02 2007 Adam Jackson <ajax@redhat.com> 6.5.2-7
- mesa-6.5.2-picify-dri-drivers.patch: Attempt to make the DRI drivers PIC.
- mesa-6.5.1-build-config.patch: Apply RPM_OPT_FLAGS to OSMesa too.

* Mon Feb 26 2007 Adam Jackson <ajax@redhat.com> 6.5.2-6
- mesa-6.5.2-libgl-visibility.patch: Fix non-exported GLX symbols (#229808)
- Require a sufficiently new libdrm at runtime too
- Make the arch macros do something sensible in the general case

* Tue Feb 20 2007 Adam Jackson <ajax@redhat.com> 6.5.2-5
- General spec cleanups
- Require current libdrm
- Build with -fvisibility=hidden
- Redo the way mesa-source is generated
- Add %%{?_smp_mflags} where appropriate

* Mon Dec 18 2006 Adam Jackson <ajax@redhat.com> 6.5.2-4
- Add i915tex and mach64 to the install set. 

* Tue Dec 12 2006 Adam Jackson <ajax@redhat.com> 6.5.2-3
- mesa-6.5.2-xserver-1.1-source-compat.patch: Add some source-compatibility
  defines to dispatch.h so the X server will continue to build.

* Mon Dec 4 2006 Adam Jackson <ajax@redhat.com> 6.5.2-2.fc6
- Fix OSMesa file listing to use %%version for DSO number.  Note that this
  will still break on Mesa 7; oh well.
- Deleted file: directfbgl.h

* Sun Dec  3 2006 Kristian Høgsberg <krh@redhat.com> 6.5.2-1.fc6
- Update to 6.5.2.

* Mon Oct 16 2006 Kristian <krh@redhat.com> - 6.5.1-8.fc6
- Add i965-interleaved-arrays-fix.patch to fix (#209318).

* Sat Sep 30 2006 Soren Sandmann <sandmann@redhat.com> - 6.5.1-7.fc6
- Update to gl-manpages-1.0.1.tar.bz2 which doesn't use symlinks. (#184547)

* Sat Sep 30 2006 Soren Sandmann <sandmann@redhat.com> - 6.5.1-7.fc6
- Remove . after popd; add .gz in %%files section. (#184547)

* Sat Sep 30 2006 Soren Sandmann <sandmann@redhat.com>
- Use better tarball for gl man pages. (#184547)

* Fri Sep 29 2006 Kristian <krh@redhat.com> - 6.5.1-6.fc6
- Add -fno-strict-aliasing to compiler flags for i965 driver.
- Add post-6.5.1-i965-fixes.patch backport of i965 fixes from mesa CVS.

* Fri Sep 29 2006 Soren Sandmann <sandamnn@redhat.com> - 6.5.1-5.fc6
- Give the correct path for man page file lists.

* Thu Sep 28 2006 Soren Sandmann <sandmann@redhat.com> - 6.5.1-5.fc6
- Add GL man pages from X R6.9.  (#184547)

* Mon Sep 25 2006 Adam Jackson <ajackson@redhat.com> - 6.5.1-4.fc6
- mesa-6.5.1-build-config.patch: Add -lselinux to osmesa builds.  (#207767)

* Wed Sep 20 2006 Kristian Høgsberg <krh@redhat.com> - 6.5.1-3.fc6
- Bump xorg-x11-proto-devel BuildRequires to 7.1-8 so we pick up the
  latest GLX_EXT_texture_from_pixmap opcodes.

* Wed Sep 20 2006 Kristian Høgsberg <krh@redhat.com> - 6.5.1-2.fc6
- Remove mesa-6.5-drop-static-inline.patch.

* Tue Sep 19 2006 Kristian Høgsberg <krh@redhat.com> 6.5.1-1.fc6
- Bump to 6.5.1 final release.
- Drop libGLw subpackage, it is now in Fedora Extras (#188974) and
  tweak mesa-6.5.1-build-config.patch to not build libGLw.
- Drop mesa-6.5.1-r300-smooth-line.patch, the smooth line fallback can
  now be prevented by enabling disable_lowimpact_fallback in
  /etc/drirc.
- Drop mesa-6.4.1-radeon-use-right-texture-format.patch, now upstream.
- Drop mesa-6.5-drop-static-inline.patch, workaround no longer necessary.

* Thu Sep  7 2006 Kristian Høgsberg <krh@redhat.com>
- Drop unused mesa-modular-dri-dir.patch.

* Tue Aug 29 2006 Kristian Høgsberg <krh@redhat.com> - 6.5.1-0.rc2.fc6
- Rebase to 6.5.1 RC2.
- Get rid of redhat-mesa-driver-install and redhat-mesa-target helper
  scripts and clean up specfile a bit.

* Mon Aug 28 2006 Kristian Høgsberg <krh@redhat.com> - 6.5.1-0.rc1.2.fc6
- Drop upstreamed patches mesa-6.5-texture-from-pixmap-fixes.patch and
  mesa-6.5-tfp-fbconfig-attribs.patch and fix
  mesa-6.4.1-radeon-use-right-texture-format.patch to not break 16bpp
  transparency.

* Fri Aug 25 2006 Adam Jackson <ajackson@redhat.com> - 6.5.1-0.rc1.1.fc6
- mesa-6.5.1-build-config.patch: Add i965 to x86-64 config.

* Wed Aug 23 2006 Kristian Høgsberg <krh@redhat.com> - 6.5.1-0.rc1.fc6
- Bump to 6.5.1 RC1.

* Tue Aug 22 2006 Kristian Høgsberg <krh@redhat.com> 6.5-26.20060818cvs.fc6
- Pull the vtxfmt patch into the selinux-awareness patch, handle exec
  mem heap init failure correctly by releasing mutex.

* Tue Aug 22 2006 Adam Jackson <ajackson@redhat.com> 6.5-25.20060818cvs.fc6
- mesa-6.5.1-r300-smooth-line.patch: Added, fakes smooth lines with aliased
  lines on R300+ cards, makes Google Earth tolerable.
- mesa-6.5-force-r300.patch: Resurrect.

* Tue Aug 22 2006 Adam Jackson <ajackson@redhat.com> 6.5-24.20060818cvs.fc6
- mesa-6.5.1-radeon-vtxfmt-cleanup-properly.patch: Fix a segfault on context
  destruction when selinux is enabled.

* Mon Aug 21 2006 Adam Jackson <ajackson@redhat.com> 6.5-23.20060818cvs.fc6
- redhat-mesa-driver-install: Reenable installing the tdfx driver. (#203295)

* Fri Aug 18 2006 Adam Jackson <ajackson@redhat.com> 6.5-22.20060818cvs.fc6
- Update to pre-6.5.1 snapshot.
- Re-add libOSMesa{,16,32}. (#186366)
- Add BuildReq: on libXp-devel due to openmotif header insanity.

* Sun Aug 13 2006 Florian La Roche <laroche@redhat.com> 6.5-21.fc6
- fix one Requires: to use the correct mesa-libGLw name

* Thu Jul 27 2006 Mike A. Harris <mharris@redhat.com> 6.5-20.fc6
- Conditionalized libGLw inclusion with new with_libGLw macro defaulting
  to 1 (enabled) for now, however since nothing in Fedora Core uses libGLw
  anymore, we will be transitioning libGLw to an external package maintained
  in Fedora Extras soon.

* Wed Jul 26 2006 Kristian Høgsberg <krh@redhat.com> 6.5-19.fc5.aiglx
- Build for fc5 aiglx repo.

* Tue Jul 25 2006 Adam Jackson <ajackson@redhat.com> 6.5-19.fc6
- Disable TLS dispatch, it is selinux-hostile.

* Tue Jul 25 2006 Adam Jackson <ajackson@redhat.com> 6.5-18.fc6
- mesa-6.5-fix-glxinfo-link.patch: lib64 fix.

* Tue Jul 25 2006 Adam Jackson <ajackson@redhat.com> 6.5-17.fc6
- mesa-6.5-fix-linux-indirect-build.patch: Added.
- mesa-6.5-fix-glxinfo-link.patch: Added.
- Build libOSMesa never instead of inconsistently; to be fixed later.
- Updates to redhat-mesa-target:
  - Always select linux-indirect when not building for DRI
  - Enable DRI to be built on PPC64 (still disabled in the spec file though)
  - MIT licence boilerplate

* Tue Jul 25 2006 Mike A. Harris <mharris@redhat.com> 6.5-16.fc6
- Remove glut-devel dependency, as nothing actually uses it that we ship.
- Added mesa-6.5-dont-libglut-me-harder-ok-thx-bye.patch to prevent libglut
  and other libs from being linked into glxgears/glxinfo even though they
  are not actually used.  This was the final package linking to freeglut in
  Fedora Core, blocking freeglut from being moved to Extras.
- Commented all of the virtual provides in the spec file to document clearly
  how they should be used by other developers in specifying build and runtime
  dependencies when packaging software which links to libGL, libGLU, and
  libGLw. (#200069)

* Mon Jul 24 2006 Adam Jackson <ajackson@redhat.com> 6.5-15.fc6
- Attempt to add selinux awareness; check if we can map executable memory
  and fail softly if not.  Removes the need for allow_execmem from huge
  chunks of the desktop.
- Disable the r300 gart fix for not compiling.

* Mon Jul 24 2006 Kristian Høgsberg <krh@redhat.com> 6.5-14.fc6
- Add mesa-6.5-r300-free-gart-mem.patch to make r300 driver free gart
  memory on context destroy.

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> 6.5-13.1.fc6
- rebuild

* Wed Jul 05 2006 Mike A. Harris <mharris@redhat.com> 6.5-13.fc6
- Added mesa-6.5-fix-opt-flags-bug197640.patch as 2nd attempt to fix OPT_FLAGS
  for (#197640).
- Ensure that redhat-mesa-driver-install creates $DRIMODULE_DESTDIR with
  mode 0755.

* Wed Jul 05 2006 Mike A. Harris <mharris@redhat.com> 6.5-12.fc6
- Maybe actually, you know, apply the mesa-6.5-glx-use-tls.patch as that might
  help to you know, actually solve the problem.  Duh.
- Use {dist} tag in Release field now.

* Wed Jul 05 2006 Mike A. Harris <mharris@redhat.com> 6.5-11
- Added mesa-6.5-glx-use-tls.patch to hopefully get -DGLX_USE_TLS to really
  work this time due to broken upstream linux-dri-* configs. (#193979)
- Pass RPM_OPT_FLAGS via OPT_FLAGS instead of via CFLAGS also for (#193979)

* Mon Jun 19 2006 Mike A. Harris <mharris@redhat.com> 6.5-10
- Bump libdrm-devel dep to trigger new ExclusiveArch test with the new package.
- Use Fedora Extras style BuildRoot tag.
- Added "Requires(post): /sbin/ldconfig" and postun to all runtime lib packages.

* Mon Jun 12 2006 Kristian Høsberg <krh@redhat.com> 6.5-9
- Add mesa-6.5-fix-pbuffer-dispatch.patch to fix pbuffer marshalling code.

* Mon May 29 2006 Kristian Høgsberg <krh@redhat.com> 6.5-8
- Bump for rawhide build.

* Mon May 29 2006 Kristian Høgsberg <krh@redhat.com> 6.5-7
- Update mesa-6.5-texture-from-pixmap-fixes.patch to include new
  tokens and change tfp functions to return void.  Yes, a new mesa
  snapshot would be nice.

* Wed May 17 2006 Mike A. Harris <mharris@redhat.com> 6.5-6
- Add "BuildRequires: makedepend" for bug (#191967)

* Tue Apr 11 2006 Kristian Høgsberg <krh@redhat.com> 6.5-5
- Bump for fc5 build.

* Tue Apr 11 2006 Adam Jackson <ajackson@redhat.com> 6.5-4
- Disable R300_FORCE_R300 hack for wider testing.

* Mon Apr 10 2006 Kristian Høgsberg <krh@redhat.com> 6.5-3
- Add mesa-6.5-noexecstack.patch to prevent assembly files from making
  libGL.so have executable stack.

* Mon Apr 10 2006 Kristian Høgsberg <krh@redhat.com> 6.5-2
- Bump for fc5 build.
- Bump libdrm requires to 2.0.1.

* Sat Apr 01 2006 Kristian Høgsberg <krh@redhat.com> 6.5-1
- Update to mesa 6.5 snapshot.
- Use -MG for generating deps and some files are not yet symlinked at
  make depend time.
- Drop mesa-6.4.2-dprintf-to-debugprintf-for-bug180122.patch and
  mesa-6.4.2-xorg-server-uses-bad-datatypes-breaking-AMD64-fdo5835.patch
  as these are upstream now.
- Drop mesa-6.4.1-texture-from-drawable.patch and add
  mesa-6.5-texture-from-pixmap-fixes.patch.
- Update mesa-modular-dri-dir.patch to apply.
- Widen libGLU glob.
- Reenable r300 driver install.
- Widen libOSMesa glob.
- Go back to patching config/linux-dri, add mesa-6.5-build-config.patch,
  drop mesa-6.3.2-build-configuration-v4.patch.
- Disable sis dri driver for now, only builds on x86 and x86-64.

* Fri Mar 24 2006 Kristian Høgsberg <krh@redhat.com> 6.4.2-7
- Set ARCH_FLAGS=-DGLX_USE_TLS to enable TLS for GL contexts.

* Wed Mar 01 2006 Karsten Hopp <karsten@redhat.de> 6.4.2-6
- Buildrequires: libXt-devel (#183479)

* Sat Feb 25 2006 Mike A. Harris <mharris@redhat.com> 6.4.2-5
- Disable the expeimental r300 DRI driver, as it has turned out to cause
  instability and system hangs for many users.

* Wed Feb 22 2006 Adam Jackson <ajackson@redhat.com> 6.4.2-4
- rebuilt

* Sun Feb 19 2006 Ray Strode <rstrode@redhat.com> 6.4.2-3
- enable texture-from-drawable patch
- add glut-devel dependency

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 6.4.2-2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Mike A. Harris <mharris@redhat.com> 6.4.2-2
- Added new "glx-utils" subpackage with glxgears and glxinfo (#173510)
- Added mesa-6.4.2-dprintf-to-debugprintf-for-bug180122.patch to workaround
  a Mesa namespace conflict with GNU_SOURCE (#180122)
- Added mesa-6.4.2-xorg-server-uses-bad-datatypes-breaking-AMD64-fdo5835.patch
  as an attempt to fix bugs (#176976,176414,fdo#5835)
- Enabled inclusion of the *EXPERIMENTAL UNSUPPORTED* r300 DRI driver on
  x86, x86_64, and ppc architectures, however the 2D Radeon driver will soon
  be modified to require the user to manually turn experimental DRI support
  on with Option "dri" in xorg.conf to test it out and report all X bugs that
  occur while using it directly to X.Org bugzilla.  (#179712)
- Use "libOSMesa.so.6.4.0604*" glob in file manifest, to avoid having to
  update it each upstream release.

* Sat Feb 04 2006 Mike A. Harris <mharris@redhat.com> 6.4.2-1
- Updated to Mesa 6.4.2
- Use "libGLU.so.1.3.0604*" glob in file manifest, to avoid having to update it
  each upstream release.

* Tue Jan 24 2006 Mike A. Harris <mharris@redhat.com> 6.4.1-5
- Added missing "BuildRequires: expat-devel" for bug (#178525)
- Temporarily disabled mesa-6.4.1-texture-from-drawable.patch, as it fails
  to compile on at least ia64, and possibly other architectures.

* Tue Jan 17 2006 Kristian Høgsberg <krh@redhat.com> 6.4.1-4
- Add mesa-6.4.1-texture-from-drawable.patch to implement protocol
  support for GLX_EXT_texture_from_drawable extension.

* Sat Dec 24 2005 Mike A. Harris <mharris@redhat.com> 6.4.1-3
- Manually copy libGLw headers that Mesa forgets to install, to fix (#173879).
- Added mesa-6.4.1-libGLw-enable-motif-support.patch to fix (#175251).
- Removed "Conflicts" lines from libGL package, as they are "Obsoletes" now.
- Do not rename swrast libGL .so version, as it is the OpenGL version.

* Tue Dec 20 2005 Mike A. Harris <mharris@redhat.com> 6.4.1-2
- Rebuild to ensure libGLU gets rebuilt with new gcc with C++ compiler fixes.
- Changed the 3 devel packages to use Obsoletes instead of Conflicts for the
  packages the files used to be present in, as this is more friendy for
  OS upgrades.
- Added "Requires: libX11-devel" to mesa-libGL-devel package (#173712)
- Added "Requires: libGL-devel" to mesa-libGLU-devel package (#175253)

* Sat Dec 17 2005 Mike A. Harris <mharris@redhat.com> 6.4.1-1
- Updated MesaLib tarball to version 6.4.1 from Mesa project for X11R7 RC4.
- Added pkgconfig dependency.
- Updated "BuildRequires: libdrm-devel >= 2.0-1"
- Added Obsoletes lines to all the subpackages to have cleaner upgrades.
- Added mesa-6.4.1-amd64-assyntax-fix.patch to work around a build problem on
  AMD64, which is fixed in the 6.4 branch of Mesa CVS.
- Conditionalize libOSMesa inclusion, and default to not including it for now.

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com> 6.4-5.1
- rebuilt

* Sun Nov 20 2005 Jeremy Katz <katzj@redhat.com> 6.4-5
- fix directory used for loading dri modules (#173679)
- install dri drivers as executable so they get stripped (#173292)

* Thu Nov 03 2005 Mike A. Harris <mharris@redhat.com> 6.4-4
- Wrote redhat-mesa-source-filelist-generator to dynamically generate the
  files to be included in the mesa-source subpackage, to minimize future
  maintenance.
- Fixed detection and renaming of software mesa .so version.

* Wed Nov 02 2005 Mike A. Harris <mharris@redhat.com> 6.4-3
- Hack: autodetect if libGL was given .so.1.5* and rename it to 1.2 for
  consistency on all architectures, and to avoid upgrade problems if we
  ever disable DRI on an arch and then re-enable it later.

* Wed Nov 02 2005 Mike A. Harris <mharris@redhat.com> 6.4-2
- Added mesa-6.4-multilib-fix.patch to instrument and attempt to fix Mesa
  bin/installmesa script to work properly with multilib lib64 architectures.
- Set and export LIB_DIR and INCLUDE_DIR in spec file 'install' section,
  and invoke our modified bin/installmesa directly instead of using
  "make install".
- Remove "include/GL/uglglutshapes.h", as it uses the GLUT license, and seems
  like an extraneous file anyway.
- Conditionalize the file manifest to include libGL.so.1.2 on DRI enabled
  builds, but use libGL.so.1.5.060400 instead on DRI disabled builds, as
  this is how upstream builds the library, although it is not clear to me
  why this difference exists yet (which was not in Xorg 6.8.2 Mesa).

* Thu Oct 27 2005 Mike A. Harris <mharris@redhat.com> 6.4-1
- Updated to new upstream MesaLib-6.4
- Updated libGLU.so.1.3.060400 entry in file manifest
- Updated "BuildRequires: libdrm-devel >= 1.0.5" to pick up fixes for the
  unichrome driver.

* Tue Sep 13 2005 Mike A. Harris <mharris@redhat.com> 6.3.2-6
- Fix redhat-mesa-driver-install and spec file to work right on multilib
  systems.
  
* Mon Sep 05 2005 Mike A. Harris <mharris@redhat.com> 6.3.2-5
- Fix mesa-libGL-devel to depend on mesa-libGL instead of mesa-libGLU.
- Added virtual "Provides: libGL..." entries for each subpackage as relevant.

* Mon Sep 05 2005 Mike A. Harris <mharris@redhat.com> 6.3.2-4
- Added the mesa-source subpackage, which contains part of the Mesa source
  code needed by other packages such as the X server to build stuff.

* Mon Sep 05 2005 Mike A. Harris <mharris@redhat.com> 6.3.2-3
- Added Conflicts/Obsoletes lines to all of the subpackages to make upgrades
  from previous OS releases, and piecemeal upgrades work as nicely as
  possible.

* Mon Sep 05 2005 Mike A. Harris <mharris@redhat.com> 6.3.2-2
- Wrote redhat-mesa-target script to simplify mesa build target selection.
- Wrote redhat-mesa-driver-install to install the DRI drivers and simplify
  per-arch conditionalization, etc.

* Sun Sep 04 2005 Mike A. Harris <mharris@redhat.com> 6.3.2-1
- Initial build.
