Summary:        Command-line tools and library for transforming PDF files
Name:           qpdf
Version:        10.6.3
Release:        1%{?_dist_release}
Group:          publishing
Vendor:         Project Vine
Distribution:   Vine Linux

# MIT: e.g. libqpdf/sha2.c
# upstream uses ASL 2.0 now, but he allowed other to distribute qpdf under
# old license (see README)
License:        Artistic 2.0
URL:            https://github.com/qpdf/qpdf
Source0:        https://github.com/qpdf/qpdf/releases/download/release-qpdf-%{version}/qpdf-%{version}.tar.gz

BuildRequires:  gnutls-devel
BuildRequires:  zlib-devel
BuildRequires:  pcre-devel
BuildRequires:  libjpeg-turbo-devel libtiff-devel
BuildRequires:  unzip

# for fix-qdf and test suite
BuildRequires:  perl
BuildRequires:  perl(Digest::MD5)

# # for autoreconf
# BuildRequires: autoconf
# BuildRequires: automake
# BuildRequires: libtool

Requires:       qpdf-libs%{?_isa} = %{version}-%{release}

%description
QPDF is a command-line program that does structural, content-preserving
transformations on PDF files. It could have been called something
like pdf-to-pdf. It includes support for merging and splitting PDFs
and to manipulate the list of pages in a PDF file. It is not a PDF viewer
or a program capable of converting PDF into other formats.


%package        libs
Summary:        QPDF library for transforming PDF files
Group:          system

%description libs
QPDF is a C++ library that inspect and manipulate the structure of PDF files.
It can encrypt and linearize files, expose the internals of a PDF file,
and do many other operations useful to PDF developers.


%package        devel
Summary:        Development files for QPDF library
Group:          programming
Requires:       qpdf-libs%{?_isa} = %{version}-%{release}

%description devel
Header files and libraries necessary
for developing programs using the QPDF library.


%package        doc
Summary:        QPDF Manual
Group:          documentation
BuildArch:      noarch
Requires:       qpdf-libs = %{version}-%{release}

%description doc
QPDF Manual


%debug_package


%prep
%setup -q


%build
# work-around check-rpaths errors
autoreconf --verbose --force --install
./autogen.sh

%configure --disable-static \
           --enable-crypto-gnutls \
           --disable-implicit-crypto \
           --enable-show-failed-test-output

%{__make} %{?_smp_mflags}


%install
%{make_install}

rm -f %{buildroot}%{_libdir}/libqpdf.la


%check
%{__make} check


%files
%license Artistic-2.0 LICENSE.txt
%{_bindir}/fix-qdf
%{_bindir}/qpdf
%{_bindir}/zlib-flate
%{_mandir}/man1/*

%files libs
%license Artistic-2.0 LICENSE.txt
%doc README.md NOTICE.md TODO ChangeLog
%{_libdir}/libqpdf*.so.*

%files devel
%doc examples/*.cc examples/*.c
%{_includedir}/*
%{_libdir}/libqpdf*.so
%{_libdir}/pkgconfig/libqpdf.pc

%files doc
%{_pkgdocdir}


%changelog
* Thu Aug 11 2022 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 10.6.3-1
- new upstream release.

* Sat Jul 31 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 10.3.2-1
- new upstream release.
- dropped ldconfig scriptlets.

* Tue Jan 29 2019 Toshiaki Ara <ara_t@384.jp> - 8.3.0-1
- update to 8.3.0
- drop Patch0 (upstream fixed)

* Tue Sep 04 2018 Toshiaki Ara <ara_t@384.jp> - 8.1.0-1
- update to 8.1.0

* Tue Jan 30 2018 Toshiaki Ara <ara_t@384.jp> - 7.1.0-1
- new upstream release.
- add BuildRequires: libjpeg-turbo-devel libtiff-devel
- drop BuildRequires: autoconf automake libtool

* Wed Jun 29 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 6.0.0-1
- new upstream release.

* Sat Jan 04 2014 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 5.1.0-2
- initial build for Vine Linux.

* Wed Dec 18 2013 Jiri Popelka <jpopelka@redhat.com> - 5.1.0-1
- 5.1.0

* Mon Oct 21 2013 Jiri Popelka <jpopelka@redhat.com> - 5.0.1-1
- 5.0.1

* Sat Aug 03 2013 Petr Pisar <ppisar@redhat.com> - 5.0.0-4
- Perl 5.18 rebuild

* Mon Jul 22 2013 Jiri Popelka <jpopelka@redhat.com> - 5.0.0-3
- change shebang to absolute path (#987040)

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 5.0.0-2
- Perl 5.18 rebuild

* Thu Jul 11 2013 Jiri Popelka <jpopelka@redhat.com> - 5.0.0-1
- 5.0.0

* Mon Jul 08 2013 Jiri Popelka <jpopelka@redhat.com> - 4.2.0-1
- 4.2.0

* Thu May 23 2013 Jiri Popelka <jpopelka@redhat.com> - 4.1.0-3
- fix 'complete manual location' note in man pages (#966534)

* Tue May 07 2013 Jiri Popelka <jpopelka@redhat.com> - 4.1.0-2
- some source files are under MIT license

* Mon Apr 15 2013 Jiri Popelka <jpopelka@redhat.com> - 4.1.0-1
- 4.1.0

* Tue Mar 05 2013 Jiri Popelka <jpopelka@redhat.com> - 4.0.1-3
- work around gcc 4.8.0 issue on ppc64 (#915321)
- properly handle overridden compressed objects

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jan 18 2013 Jiri Popelka <jpopelka@redhat.com> 4.0.1-1
- 4.0.1

* Wed Jan 02 2013 Jiri Popelka <jpopelka@redhat.com> 4.0.0-1
- 4.0.0

* Fri Sep 07 2012 Jiri Popelka <jpopelka@redhat.com> 3.0.2-1
- 3.0.2

* Thu Aug 16 2012 Jiri Popelka <jpopelka@redhat.com> 3.0.1-3
- the previously added requirement doesn't need to be arch-specific

* Thu Aug 16 2012 Jiri Popelka <jpopelka@redhat.com> 3.0.1-2
- doc subpackage requires libs subpackage due to license file (#848466)

* Wed Aug 15 2012 Jiri Popelka <jpopelka@redhat.com> 3.0.1-1
- initial spec file
